==> cmtk_2.1.0.orig.tar.gz: cmtk-2.1.0/libs/IO/cmtkClassStreamAffineXform.h <==
/*
//
//  Copyright 1997-2009 Torsten Rohlfing
//
//  Copyright 2004-2010 SRI International
//
//  This file is part of the Computational Morphometry Toolkit.
//
//  http://www.nitrc.org/projects/cmtk/
//
//  The Computational Morphometry Toolkit is free software: you can
//  redistribute it and/or modify it under the terms of the GNU General Public
//  License as published by the Free Software Foundation, either version 3 of
//  the License, or (at your option) any later version.
//
//  The Computational Morphometry Toolkit is distributed in the hope that it
//  will be useful, but WITHOUT ANY WARRANTY; without even the implied
//  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License along
//  with the Computational Morphometry Toolkit.  If not, see
//  <http://www.gnu.org/licenses/>.
//
//  $Revision: 2398 $
//
//  $LastChangedDate: 2010-10-05 14:54:37 -0700 (Tue, 05 Oct 2010) $
//
//  $LastChangedBy: torstenrohlfing $
//
*/

#ifndef __cmtkClassStreamAffineXform_h_included_
#define __cmtkClassStreamAffineXform_h_included_

#include <cmtkconfig.h>

#include <IO/cmtkClassStream.h>
#include <Base/cmtkAffineXform.h>

namespace
cmtk
{

/** \addtogroup IO */
//@{

/// Write affine transformation object.
ClassStream& operator << ( ClassStream& stream, const AffineXform& affineXform );

/// Read affine transformation.
ClassStream& operator >> ( ClassStream& stream, AffineXform::SmartPtr& affineXform );

/// Read affine transformation.
ClassStream& operator >> ( ClassStream& stream, AffineXform& affineXform );

//@}

} // namespace cmtk

#endif // #ifndef __cmtkClassStreamAffineXform_h_included_

==> cmtk_3.3.1.orig.tar.gz: cmtk-3.3.1/libs/IO/cmtkClassStreamAffineXform.h <==
/*
//
//  Copyright 1997-2009 Torsten Rohlfing
//
//  Copyright 2004-2010 SRI International
//
//  This file is part of the Computational Morphometry Toolkit.
//
//  http://www.nitrc.org/projects/cmtk/
//
//  The Computational Morphometry Toolkit is free software: you can
//  redistribute it and/or modify it under the terms of the GNU General Public
//  License as published by the Free Software Foundation, either version 3 of
//  the License, or (at your option) any later version.
//
//  The Computational Morphometry Toolkit is distributed in the hope that it
//  will be useful, but WITHOUT ANY WARRANTY; without even the implied
//  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License along
//  with the Computational Morphometry Toolkit.  If not, see
//  <http://www.gnu.org/licenses/>.
//
//  $Revision: 4344 $
//
//  $LastChangedDate: 2012-05-11 14:51:08 -0700 (Fri, 11 May 2012) $
//
//  $LastChangedBy: torstenrohlfing $
//
*/

#ifndef __cmtkClassStreamAffineXform_h_included_
#define __cmtkClassStreamAffineXform_h_included_

#include <cmtkconfig.h>

#include <IO/cmtkClassStreamInput.h>
#include <IO/cmtkClassStreamOutput.h>

#include <Base/cmtkAffineXform.h>

namespace
cmtk
{

/** \addtogroup IO */
//@{

/// Write affine transformation object.
ClassStreamOutput& operator << ( ClassStreamOutput& stream, const AffineXform& affineXform );

/// Read affine transformation.
ClassStreamInput& operator >> ( ClassStreamInput& stream, AffineXform::SmartPtr& affineXform );

/// Read affine transformation.
ClassStreamInput& operator >> ( ClassStreamInput& stream, AffineXform& affineXform );

//@}

} // namespace cmtk

#endif // #ifndef __cmtkClassStreamAffineXform_h_included_
